tdub.batch
----------

A module for running batch jobs (currently targets the US ATLAS BNL
cluster).

.. currentmodule:: tdub.batch

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   add_condor_arguments
   condor_preamble
   create_condor_workspace

Reference
^^^^^^^^^

.. autofunction:: add_condor_arguments
.. autofunction:: condor_preamble
.. autofunction:: create_condor_workspace
